#xhostplus-social-viewlet {
    margin-top:3em;
}

#xhostplus-social-viewlet * {
    vertical-align:top !important;
    margin-right:1em;
}

/*** Fixes for Linked-In button ***/

.IN-widget span {
    float:left;
}
